# Changelog

Notable changes and version history.

| Version | Date  | Comment |
|---------|-------|-------|
| [v1.0-beta-2](https://github.com/wsp-sag/network_wrangler/releases/tag/v1.0-beta-1) | 20204-10-15 | Bug fixes in scenario loading, projectcard API and compatibility of transit net with roadway deletions. Some additional performance improvements. |
| [v1.0-beta-1](https://github.com/wsp-sag/network_wrangler/releases/tag/v1.0-beta-1) | 20204-10-9 | Feature-complete for 1.0 |
| [v1.0-alpha-2](https://github.com/wsp-sag/network_wrangler/releases/tag/v1.0-alpha.2) | 2024-10-8 | Testing for Met Council |
| [v1.0-alpha-1](https://github.com/wsp-sag/network_wrangler/releases/tag/v1.0-alpha.1) | 2024-07-17 | Full refactor |
| [v0.2.0-alpha](https://github.com/wsp-sag/network_wrangler/releases/tag/v0.2.0-alpha) | 2020-09-16 | - |
| [v0.1.0-alpha](https://github.com/wsp-sag/network_wrangler/releases/tag/v0.1.0-alpha) | 2020-09-09 | - |
| [0.0.2](https://github.com/wsp-sag/network_wrangler/releases/tag/0.0.2) | 2020-02-05 | - |
